@@ -1,4 +1,6 @@
+"""The main entry point for Jupyter Server."""
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     from jupyter_server import serverapp as app
+
     app.launch_new_instance()
